
.. image:: _static/nurse.jpg
    :align: right
    :alt: PyGTKHelpers, because being stabbed in the eye hurts, somewhat

What is PyGTKHelpers?
=====================

PyGTKHelpers is a library to assist the building of PyGTK applications. It is
intentionally designed to be *non-frameworky*, and blend well with your
particular style of PyGTK development.

PyGTKHelpers provides a number of widespread features including: View
delegation, MVC, mixed GtkBuilder/Python views, widget proxying, signal
auto-connection, object-base lists and trees, a number of helper widgets,
utility functions for assisting creating new GObject types, unit testing
helpers and utilities to help debug PyGTK applications.

Table of contents
~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   downloads
   community
   doc

PyGTKHelpers attempts to adhere to good practice, and is well unit tested. We
generally believe it to be awesome, and present it to the community under the
LGPL license, which can be viewed online at 
http://www.gnu.org/licenses/lgpl-3.0.txt.


